==> SexyMap-v1.8.4.zip: SexyMap/localization/zhCN.lua <==

if GetLocale() ~= "zhCN" then return end
local _, sm = ...
local L = sm.L
L["1. Background"] = "1、背景"
L["2. Border"] = "2、边框"
L["3. Artwork"] = "3、装饰"
L["4. Overlay"] = "4、覆盖"
L["5. Highlight"] = "5、高亮"
L["Add Blend (additive)"] = "添加混合（附加式）"
L["Addon Buttons"] = "插件按钮"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "允许SexyMap 拖动依附在小地图上的按钮。如果你用其他的插件来拖动按钮，请关闭此功能。"
L["Alpha Key (1-bit alpha)"] = "透明键（少量透明度）"
L["Always"] = "总是"
L["Armored Man"] = "耐久度"
L["A static amount to rotate the texture by."] = "材质固定旋转量。"
L["Auto Zoom-Out Delay"] = "自动缩放延时"
L["Backdrop Color"] = "背景颜色"
L["Backdrop Insets"] = "背景镶边"
L["Background Color"] = "背景颜色"
L["Background/edge"] = "背景/边缘"
L["Background Texture"] = "背景材质"
L["Blend Mode"] = "混合模式"
L["Blend (normal)"] = "混合效果（普通）"
L["Border Color"] = "边框颜色"
L["Border Edge Size"] = "边框边缘尺寸"
L["Borders"] = "边框"
L["Border Texture"] = "边框材质"
L["Boss Frames"] = "首领框体"
L["Buttons"] = "按钮"
L["Calendar"] = "日历"
L["Capture Bars"] = "占领进度条"
L["Challenge Mode Button (When Available)"] = "挑战模式按钮（可用时）"
L["Circle"] = "圆形"
L["Clamp to screen"] = "固定在屏幕上"
L["Clear & start over"] = "重置"
L["Clear the current borders and start fresh"] = "清除当前边框并重新开始设置"
L["Clock"] = "时钟"
L["Coordinates"] = "坐标"
L["Create a new border"] = "创建新边框"
L["Current Borders"] = "当前边框"
L["Delete"] = "删除"
L["Diamond"] = "钻石形"
L["Disable (opaque)"] = "禁用（不透明）"
L["Disable Rotation"] = "禁用旋转"
L["Drag Radius"] = "拖动半径"
L["Dungeon Difficulty Indicator (When Available)"] = "副本难度指示（可用时）"
L["Dynamic Buttons"] = "动态按钮"
L["Enable"] = "启用"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "为小地图启用一个背景和边框。使设置方形边框变得更简单。"
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "启用 HUD 地图。这十分利于采集，但由于技术原因，HUD 地图和常规小地图无法同时显示。显示 HUD 地图将暂时关闭常规小地图。"
L["Enable Coordinates"] = "启用坐标"
L["Enable Hudmap"] = "启用HUD地图"
L["Enable Minimap Fader"] = "启用小地图淡出"
L["Enable Movers"] = "启用框体移动"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "输入名称创建新边框。可以用任何你想用来帮助你识别此边框的名称。"
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "输入完整的材质路径才能使用。建议使用类似 |cffff6600TexBrowser|r 的功能来找到需要使用材质。"
L["Entry Options"] = "基本设置"
L["Faded Circle (Large)"] = "圆形淡出（大）"
L["Faded Circle (Small)"] = "圆形淡出（小）"
L["Faded Square"] = "方形淡出"
L["Fader"] = "淡出"
L["Font"] = "字体"
L["Font Color"] = "字体颜色"
L["Font Size"] = "字体尺寸"
L["Force a square texture. Fixed distortion on square textures."] = "强制填充一个方形材质。修正方形材质上的变形失真。"
L["GatherMate is a resource gathering helper mod. Installing it allows you to have resource pins on your HudMap."] = "GatherMate 是一款采集助手类插件。安装 GatherMate 可以在 HUD 地图上显示资源点。"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "公会副本难度指示（可用时）"
L["Heart"] = "心形"
L["Hexagon"] = "六边形"
L["Hide default border"] = "隐藏默认边框"
L["Hide the default border on the minimap."] = "隐藏小地图默认边框。"
L["Horizontal Nudge"] = "水平位移"
L["Horizontal Position"] = "水平位置"
L["Hover Opacity"] = "悬停不透明"
L["HUD Color"] = "HUD颜色"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds)"] = "如果你放大地图，此功能会在选择的时间（秒）后自动缩小。"
L["Keybinding"] = "按键绑定"
L["Layer"] = "层级"
L["Let SexyMap control button visibility"] = "SexyMap管理按钮可见性"
L["Let SexyMap handle button dragging"] = "SexyMap接管按钮拖动"
L["Lock Button Dragging"] = "锁定按钮拖动"
L["Lock Coordinates"] = "锁定坐标"
L["Lock Minimap"] = "锁定小地图"
L["Lock Movers"] = "锁定框体移动"
L["Map Button"] = "地图按钮"
L["Minimap shape"] = "小地图外形"
L["Mod Blend (modulative)"] = "模块混合（模块式）"
L["Movers"] = "描点"
L["Movers Warning"] = "警告：不正式支持此功能，预计使用此功能时，如污点、任务追踪列表的丢失或首领框架的跳跃问题。暴雪框架，如任务追踪和首领血量不被移动，我建议你使用插件取代这些框架，例如：首领血量框体。"
L["Name"] = "名称"
L["Never"] = "从不"
L["New Mail Indicator (When Available)"] = "新邮件指示（可用时）"
L["Normal Opacity"] = "普通不透明"
L["Objectives Tracker"] = "物品追踪"
L["Octagon"] = "八边形"
L["On Hover"] = "悬停时"
L["Opacity"] = "不透明"
L["Open TexBrowser"] = "打开TexBrowser"
L["Ping"] = "点击小地图"
L["Preset"] = "预设配置"
L["Prevent the minimap from being moved off the screen"] = "防止小地图被移出屏幕外"
L["Profiles"] = "配置文件"
L["Queue Status Button (When Available)"] = "排队状态按钮（可用时）"
L["Really delete this border?"] = "确定删除此边框效果？"
L["Really delete this preset? This can't be undone."] = "确定删除此预设效果？此操作将无法被恢复。"
L["Reset Position"] = "重置位置"
L["Right Click Configure"] = "右键点击配置"
L["Right clicking the map will open the SexyMap options"] = "右键点击地图打开SexyMap设置"
L["Rotation Speed (seconds)"] = "旋转速度"
L["Rounded - Bottom Left"] = "方形圆角-左下"
L["Rounded - Bottom Right"] = "方形圆角-右下"
L["Rounded - Top Left"] = "方形圆角-左上"
L["Rounded - Top Right"] = "方形圆角-右上"
L["Route 66"] = "66路形"
L["Routes plots the shortest distance between resource nodes. Install it to show farming routes on your HudMap."] = "显示最近的资源点间的采集路线。加载此功能可在 HUD 地图上显示采集路线。"
L["Save current settings as preset..."] = "将当前设置保存为预设配置…"
L["Scale"] = "缩放"
L["Select a preset to load settings from. This will erase any of your current borders."] = "选择一个预设配置。这样做会清除所有你当前正在使用的边框。"
L["Select preset to load"] = "选择要加载的预设配置"
L["SharedMedia Border"] = "SharedMedia边框"
L["SharedMedia Texture"] = "SharedMedia材质"
L["Show inside chat"] = "在聊天显示"
L["Show on minimap"] = "在迷你地图显示"
L["Show %s:"] = "显示 %s:"
L["Show who pinged"] = "显示谁点击了小地图"
L["Snowflake"] = "雪花形"
L["Square"] = "方形"
L["Standard Buttons"] = "系统按钮"
L["Static Rotation"] = "固定旋转"
L["TexBrowser Not Installed"] = "没有安装TexBrowser"
L["Text Color"] = "文本颜色"
L["Texture"] = "材质"
L["Texture Options"] = "材质选项"
L["Texture Path"] = "材质路径"
L["Texture Tint"] = "材质着色"
L["Text Width"] = "文本宽度"
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "材质旋转速度。设置为“0”时不旋转。"
L["This will wipe out any current settings!"] = "这样做将清除所有当前设置！"
L["Tile Background"] = "平铺背景"
L["Tile Size"] = "平铺尺寸"
L["Tracking Button"] = "追踪按钮"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "如果你用其他的插件来管理按钮是否显示在小地图，请关闭此功能。"
L["Use GatherMate pins"] = "显示GatherMate资源点"
L["Use QuestHelper pins"] = "使用QuestHelper资源点"
L["Use Routes"] = "显示路线"
L["Vehicle Seat"] = "载具座位"
L["Vertical Nudge"] = "垂直位移"
L["Vertical Position"] = "垂直位置"
L["Video Recording Button (Mac OSX Only, When Available)"] = "饰品录制按钮（仅限Mac OSX，可用时）"
L["Voice Chat Button (When Available)"] = "语音聊天按钮（可用时）"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "为小地图设置背景和边缘可用任意框体。便于为小地图创建固定的方形背景图案。"
L["Zone Text"] = "地区文本"
L["Zoom In Button"] = "放大按钮"
L["Zoom Out Button"] = "缩小按钮"

==> SexyMap-v7.3.3.zip: SexyMap/localization/zhCN.lua <==

if GetLocale() ~= "zhCN" then return end
local _, sm = ...
local L = sm.L
L["1. Background"] = "1、背景"
L["2. Border"] = "2、边框"
L["3. Artwork"] = "3、装饰"
L["4. Overlay"] = "4、覆盖"
L["5. Highlight"] = "5、高亮"
L["Add Blend (additive)"] = "添加混合（附加式）"
L["Addon Buttons"] = "插件按钮"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "一个全局配置文件已经存在，改变到此配置文件将会重载用户界面，确定？"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "允许 SexyMap 拖动依附在小地图上的按钮。如果你用其他的插件来拖动按钮，请关闭此功能。"
L["Alpha Key (1-bit alpha)"] = "透明键（少量透明度）"
L["Always"] = "总是"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "确定想要改回使用特定角色的配置？这将会重载用户界面。"
L["Armored Man"] = "耐久度"
L["A static amount to rotate the texture by."] = "材质固定旋转量。"
L["Auto Zoom-Out Delay"] = "自动缩放延时"
L["Backdrop Color"] = "背景颜色"
L["Backdrop Insets"] = "背景镶边"
L["Background Color"] = "背景颜色"
L["Background/edge"] = "背景/边缘"
L["Background Texture"] = "背景材质"
L["Blend Mode"] = "混合模式"
L["Blend (normal)"] = "混合效果（普通）"
L["Border Color"] = "边框颜色"
L["Border Edge Size"] = "边框边缘尺寸"
L["Borders"] = "边框"
L["Border Texture"] = "边框材质"
L["Boss Frames"] = "首领框体"
L["Buttons"] = "按钮"
L["Calendar"] = "日历"
L["Capture Bars"] = "占领进度条"
L["Challenge Mode Button (When Available)"] = "挑战模式按钮（可用时）"
L["Circle"] = "圆形"
L["Clamp to screen"] = "固定在屏幕上"
L["Clear & start over"] = "重置"
L["Clear the current borders and start fresh"] = "清除当前边框并重新开始设置"
L["Clock"] = "时钟"
L["Coordinates"] = "坐标"
L["Copy a Profile"] = "复制配置文件"
L["Copying this profile will reload your UI, are you sure?"] = "复制此配置文件将重新加载用户界面，确定？"
L["Create a new border"] = "创建新边框"
L["Current Borders"] = "当前边框"
L["Default Presets"] = "默认设置"
L["Delete"] = "删除"
L["Delete a Profile"] = "删除配置文件"
L["Diamond"] = "钻石形"
L["Disable (opaque)"] = "禁用（不透明）"
L["Disable Rotation"] = "禁用旋转"
L["Disabling the movers will make them reset next time you relog, are you sure?"] = "禁用锚点将在下次登录时重置，确定？"
L["Drag Radius"] = "拖动半径"
L["Dungeon Difficulty Indicator (When Available)"] = "副本难度指示（可用时）"
L["Dynamic Buttons"] = "动态按钮"
L["Enable"] = "启用"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "为小地图启用一个背景和边框。使设置方形边框变得更简单。"
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "启用 HUD 地图。这十分利于采集，但由于技术原因，HUD 地图和常规小地图无法同时显示。显示 HUD 地图将暂时关闭常规小地图。"
L["Enable Coordinates"] = "启用坐标"
L["Enable Hudmap"] = "启用 HUD 地图"
L["Enable Minimap Fader"] = "启用小地图淡出"
L["Enable Movers"] = "启用锚点"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "输入名称创建新边框。可以用任何你想用来帮助你识别此边框的名称。"
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "输入完整的材质路径才能使用。建议使用类似 |cffff6600TexBrowser|r 的功能来找到需要使用材质。"
L["Entry Options"] = "基本设置"
L["Faded Circle (Large)"] = "圆形淡出（大）"
L["Faded Circle (Small)"] = "圆形淡出（小）"
L["Faded Square"] = "方形淡出"
L["Fader"] = "淡出"
L["Font"] = "字体"
L["Font Color"] = "字体颜色"
L["Font Size"] = "字体尺寸"
L["Force a square texture. Fixed distortion on square textures."] = "强制填充一个方形材质。修正方形材质上的变形失真。"
L["Garrison Button (When Available)"] = "要塞按钮（当可用时）"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "公会副本难度指示（可用时）"
L["Heart"] = "心形"
L["Height"] = "高度"
L["Hexagon"] = "六边形"
L["Hide default border"] = "隐藏默认边框"
L["Hide the default border on the minimap."] = "隐藏小地图默认边框。"
L["Horizontal Nudge"] = "水平位移"
L["Horizontal Position"] = "水平位置"
L["Hover Opacity"] = "悬停不透明"
L["HUD Color"] = "HUD颜色"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "如果在地图中缩放，此功能会在所选择的一段时间（秒）后自动缩小。使用值0将禁用自动缩小。"
L["Keybinding"] = "按键绑定"
L["Layer"] = "层级"
L["Let SexyMap control button visibility"] = "SexyMap 管理按钮可见性"
L["Let SexyMap handle button dragging"] = "SexyMap 接管按钮拖动"
L["Lock Button Dragging"] = "锁定按钮拖动"
L["Lock Coordinates"] = "锁定坐标"
L["Lock Minimap"] = "锁定小地图"
L["Lock Movers"] = "锁定锚点"
L["Map Button"] = "地图按钮"
L["Minimap shape"] = "小地图外形"
L["Mod Blend (modulative)"] = "模块混合（模块式）"
L["Movers"] = "描点"
L["Movers Warning"] = "警告：不正式支持此功能，预计使用此功能时，如污点、任务追踪列表的丢失或首领框架的跳跃问题。暴雪框架，如任务追踪和首领血量不被移动，我建议你使用插件取代这些框架，例如：首领血量框体。"
L["Name"] = "名称"
L["Never"] = "从不"
L["New Mail Indicator (When Available)"] = "新邮件指示（可用时）"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "没有全局配置文件存在，当前的配置文件将会复制用于全局配置文件，确定？这也将会重载用户界面。"
L["Normal Opacity"] = "普通不透明"
L["Objectives Tracker"] = "物品追踪"
L["Octagon"] = "八边形"
L["On Hover"] = "悬停时"
L["Opacity"] = "不透明"
L["Open TexBrowser"] = "打开 TexBrowser"
L["Ping"] = "点击小地图"
L["Preset"] = "预设配置"
L["Prevent the minimap from being moved off the screen"] = "防止小地图被移出屏幕外"
L["Profiles"] = "配置文件"
L["Queue Status (PvP/LFG) Button (When Available)"] = "查询状态（PvP/寻找队伍）按钮（如可用）"
L["Quickly change the look of your minimap by using a minimap preset."] = "快速使用预设小地图预设更改小地图样式。"
L["Really delete this border?"] = "确定删除此边框效果？"
L["Really delete this preset? This can't be undone."] = "确定删除此预设效果？此操作将无法被恢复。"
L["Really delete this profile?"] = "确定删除此配置文件？"
L["(Requires button visibility control in the Buttons menu)"] = "（菜单按钮里需要按钮的可见性控制）"
L["Reset Current Profile"] = "重置当前配置文件"
L["Reset Position"] = "重置位置"
L["Resetting this profile will reload your UI, are you sure?"] = "重置此配置文件将重新加载用户界面，确定？"
L["Right Click Configure"] = "右键点击配置"
L["Right clicking the map will open the SexyMap options"] = "右键点击地图打开 SexyMap 设置"
L["Rotation Speed (seconds)"] = "旋转速度"
L["Rounded - Bottom Left"] = "方形圆角-左下"
L["Rounded - Bottom Right"] = "方形圆角-右下"
L["Rounded - Top Left"] = "方形圆角-左上"
L["Rounded - Top Right"] = "方形圆角-右上"
L["Route 66"] = "66路形"
L["Save current settings as preset..."] = "将当前设置保存为预设配置…"
L["Scale"] = "缩放"
L["Select a preset to load settings from. This will erase any of your current borders."] = "选择一个预设配置。这样做会清除所有你当前正在使用的边框。"
L["Select preset to load"] = "选择要加载的预设配置"
L["SharedMedia Border"] = "SharedMedia 边框"
L["SharedMedia Texture"] = "SharedMedia 材质"
L["Show inside chat"] = "在聊天显示"
L["Show North Tag"] = "显示指北针"
L["Show on minimap"] = "在迷你地图显示"
L["Show %s:"] = "显示 %s："
L["Show who pinged"] = "显示谁点击了小地图"
L["Snowflake"] = "雪花形"
L["Spice up your minimap with some sexy options."] = "为你的小地图增趣添彩，并包含一些性感选项。"
L["Square"] = "方形"
L["Standard Buttons"] = "系统按钮"
L["Static Rotation"] = "固定旋转"
L["TexBrowser Not Installed"] = "没有安装 TexBrowser"
L["Text Color"] = "文本颜色"
L["Texture"] = "材质"
L["Texture Options"] = "材质选项"
L["Texture Path"] = "材质路径"
L["Texture Tint"] = "材质着色"
L["Text Width"] = "文本宽度"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "HudMap 支持多数插件。如有下面任一插件被安装，将会在 HudMap 中显示。"
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "材质旋转速度。设置为“0”时不旋转。"
L["This will wipe out any current settings!"] = "这样做将清除所有当前设置！"
L["Tile Background"] = "平铺背景"
L["Tile Size"] = "平铺尺寸"
L["Toggle HudMap On/Off"] = "切换 HUD 地图"
L["Tracking Button"] = "追踪按钮"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "如果你用其他的插件来管理按钮是否显示在小地图，请关闭此功能。"
L["Use Global Profile"] = "使用全局配置文件"
L["User-Submitted Presets"] = "用户提交的设置"
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "希望每个角色使用使用全局配置文件，或每个独立角色使用特定角色配置文件。"
L["Vehicle Seat"] = "载具座位"
L["Vertical Nudge"] = "垂直位移"
L["Vertical Position"] = "垂直位置"
L["Visibility"] = "可见性"
L["Voice Chat Button (When Available)"] = "语音聊天按钮（可用时）"
L["Width"] = "宽度"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "为小地图设置背景和边缘可用任意框体。便于为小地图创建固定的方形背景图案。"
L["Zone Text"] = "地区文本"
L["Zoom In Button"] = "放大按钮"
L["Zoom Out Button"] = "缩小按钮"

--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
